import warnings

from .core import UnitedStates
from ..registry_tools import iso_register


@iso_register('US-MT')
class Montana(UnitedStates):
    """Montana"""
    include_election_day_even = True

    def get_variable_days(self, year):
        warnings.warn(
            "Montana states is supposed to observe General Election Day on "
            "even years, but for some reason some sources are including it "
            "in 2019. Please use with care."
        )
        return super().get_variable_days(year)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import io
from os.path import join, dirname, abspath
from setuptools import setup, find_packages


def read_relative_file(filename):
    """
    Return the contents of the given file.

    Its path is supposed relative to this module.
    """
    path = join(dirname(abspath(__file__)), filename)
    with io.open(path, encoding='utf-8') as f:
        return f.read()


NAME = 'workalendar'
DESCRIPTION = 'Worldwide holidays and working days helper and toolkit.'
REQUIREMENTS = [
    'skyfield',
    'skyfield-data',
    'python-dateutil',
    'lunardate',
    'pytz',
    'pyCalverter',
    'pyluach',
    'setuptools>=1.0',
]
version = '9.0.0'
__VERSION__ = version

params = dict(
    name=NAME,
    description=DESCRIPTION,
    packages=find_packages(),
    version=__VERSION__,
    long_description=read_relative_file('README.rst'),
    author='Bruno Bord',
    author_email='bruno.bord@people-doc.com',
    url='https://github.com/peopledoc/workalendar',
    license='MIT License',
    include_package_data=True,
    install_requires=REQUIREMENTS,
    zip_safe=False,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
)

if __name__ == '__main__':
    setup(**params)



from ..core import WesternCalendar, ChristianMixin
from ..registry_tools import iso_register


@iso_register('EE')
class Estonia(WesternCalendar, ChristianMixin):
    'Estonia'

    include_good_friday = True
    include_easter_sunday = True
    include_whit_sunday = True
    whit_sunday_label = 'Nelipühade 1. püha'
    include_christmas_eve = True
    include_christmas = True
    include_boxing_day = True
    boxing_day_label = "Teine jõulupüha"

    FIXED_HOLIDAYS = WesternCalendar.FIXED_HOLIDAYS + (
        (2, 24, "Independence Day"),
        (5, 1, "Kevadpüha"),
        (6, 23, "Võidupüha"),
        (6, 24, "Jaanipäev"),
        (8, 20, "Taasiseseisvumispäev")
    )



from ..registry_tools import iso_register
from .core import UnitedStates


@iso_register('US-IA')
class Iowa(UnitedStates):
    """Iowa"""
    include_thanksgiving_friday = True
    include_columbus_day = False
    include_federal_presidents_day = False



from ..core import WesternCalendar, ChristianMixin
from ..registry_tools import iso_register


@iso_register('BG')
class Bulgaria(WesternCalendar, ChristianMixin):
    'Bulgaria'

    FIXED_HOLIDAYS = WesternCalendar.FIXED_HOLIDAYS + (
        (3, 3, "Liberation Day"),  # Ден на Освобождението на Б
        (5, 1, "International Workers' Day"),  # Ден на труда и на междунар
        (5, 6, "Saint George's Day"),  # Гергьовден, ден на храброс
        (5, 24, "Saints Cyril & Methodius Day"),  # Ден на българската просвет
        (9, 6, "Unification Day"),  # Ден на Съединението
        (9, 22, "Independence Day"),  # Ден на независимостта на Б
        # wikipedia says Non-attendance day for schools, otherwise a working da
        # (11, 1, "National Awakening Day"),  # Ден на народните будители

    )

    include_easter_sunday = True
    include_easter_monday = True
    include_christmas_eve = True  # Бъдни вечер
    include_christmas = True  # Рождество Христово
    include_boxing_day = True

    # wikipedia says The Bulgarians have two days of Christmas,
    # both called Christmas Day
    boxing_day_label = "Christmas"



from ..core import WesternCalendar, OrthodoxMixin
from ..registry_tools import iso_register


@iso_register('GR')
class Greece(OrthodoxMixin, WesternCalendar):
    'Greece'

    FIXED_HOLIDAYS = WesternCalendar.FIXED_HOLIDAYS + (
        (3, 25, "Independence Day"),
        (5, 1, "Labour Day"),
        (10, 28, "Ohi Day"),
    )
    include_epiphany = True
    include_clean_monday = True
    include_annunciation = True
    include_good_friday = True
    include_easter_sunday = True
    include_easter_monday = True
    include_whit_sunday = True
    whit_sunday_label = "Pentecost"
    include_whit_monday = True
    include_assumption = True
    include_boxing_day = True
    boxing_day_label = "Glorifying Mother of God"
